@@ -37,9 +37,9 @@ use strict;
 use warnings FATAL => 'all';
 
 use App::Dochazka::Model;
-use constant ATTRS => qw( sid schedule remark disabled );
+use constant ATTRS => qw( sid scode schedule remark disabled );
 
-our $VERSION = '0.185';
+our $VERSION = '0.188';
 
 BEGIN {
     App::Dochazka::Model::boilerplate( __PACKAGE__, ATTRS );
